import dotenv from 'dotenv';
import { getClient } from './client';
import {
    Enums_Currency_Enum,
    getSdk,
    User_ProfileFragment,
} from 'gql/generated/server';
import { faker } from '@faker-js/faker';
import { randomUUID } from 'crypto';
dotenv.config();

const port = process.env.PORT || 8084;
const client = getClient();

const sdk = getSdk(client);

async function main() {
    while (true) {
        try {
            const userId = randomUUID();
            const name = faker.name.findName();
            const email = faker.internet.email();
            const user = sdk.createUser({ input: { id: userId, email, name } });

            console.log('added user');

            const listingId = randomUUID();
            const listingTitle = faker.commerce.productName();
            const listingDescription = faker.commerce.productDescription();
            const listingPrice = +faker.commerce.price(50, 1000, 2);
            const listing = sdk.createListing({
                input: {
                    id: listingId,
                    title: listingTitle,
                    description: listingDescription,
                    price: listingPrice,
                    creator_id: (await user).insert_app_users_one?.id,
                    currency: Enums_Currency_Enum.Czk,
                },
            });

            console.log('added listing');

            const photoId = randomUUID();
            const photoLink = faker.image.cats(500, 500, true);
            const photo = sdk.addPhoto({
                photo: {
                    id: photoId,
                    link: photoLink,
                    listing_id: (await listing).insert_app_listings_one?.id,
                },
            });

            console.log('added photo');

            sdk.editListing({
                id: { id: listingId },
                input: {
                    id: listingId,
                    title: listingTitle,
                    description: listingDescription,
                    price: listingPrice,
                    creator_id: (await user).insert_app_users_one?.id,
                    currency: Enums_Currency_Enum.Czk,
                    thumbnail_id: (await photo).insert_app_photos_one?.id,
                },
            });

            console.log('added listing thumbnail');
        } catch (error) {}
    }
}

main();
