import { Dropzone } from '@components/common/forms/Dropzone';
import { FormRadioGroup } from '@components/common/forms/FormRadioGroup';
import { listingOptions } from '@components/common/forms/FormRadioGroup/listingTypeOptions';
import { FormTextInput } from '@components/common/forms/FormTextInput';
import { Button } from '@mui/material';
import React, { FC, useEffect } from 'react';
import { useForm } from 'react-hook-form';
import { theme_dark } from 'theme';
import { PrimaryButton, Stack } from 'ui';
import { FormTextArea } from '@components/common/forms/FormTextArea';
import Head from 'next/head';
import { Form_ListingFragment } from 'gql/generated/react';
import { useDropzoneFiles } from '@hooks/useDropzoneFiles';
import { useFormUpsertListing } from '@hooks/useFormUpsertListing';

export interface ListingFormProps {
    initialListing?: Form_ListingFragment;
}
export type ListingFormType = FC<ListingFormProps>;

export const ListingForm: ListingFormType = ({ initialListing }) => {
    const { handleSubmit, reset, control, getValues } =
        useForm<Form_ListingFragment>();

    useEffect(() => {
        reset(initialListing);
    }, [reset, initialListing]);

    const { onSubmit } = useFormUpsertListing(getValues);

    const {
        files,
        errors,
        onDrop,
        onDropRejected,
        clearErrors,
        deleteFile,
        deleteFiles,
    } = useDropzoneFiles();

    return (
        <form>
            <Head>
                <title>Create Listing</title>
            </Head>

            <Stack direction={'column'} gap={'1rem'}>
                <FormRadioGroup
                    key={'type'}
                    control={control}
                    label={'Listing type'}
                    name={'is_selling'}
                    options={listingOptions}
                />

                <FormTextInput
                    key={'title'}
                    control={control}
                    label="Title"
                    name="title"
                />

                <FormTextArea
                    key={'description'}
                    control={control}
                    label="Description"
                    name="description"
                />

                <Stack direction={'row'} gap={theme_dark.margins.defaultCard}>
                    <FormTextInput
                        key={'price'}
                        control={control}
                        label="Price"
                        name="price"
                    />

                    <FormTextInput
                        key={'currency'}
                        control={control}
                        label="Currency"
                        name="currency"
                    />
                </Stack>

                <Dropzone
                    errors={errors}
                    files={files}
                    onDropRejected={onDropRejected}
                    onDrop={onDrop}
                    clearFiles={deleteFile}
                    clearErrors={clearErrors}
                />

                <Stack direction={'row'} gap={theme_dark.margins.defaultCard}>
                    <PrimaryButton onClick={handleSubmit(onSubmit)}>
                        Submit
                    </PrimaryButton>

                    <Button
                        onClick={() => {
                            reset();
                            deleteFiles();
                        }}
                        variant={'outlined'}
                    >
                        Reset
                    </Button>
                </Stack>
            </Stack>
        </form>
    );
};
