import { CardPrice } from '@components/common/ListingCard/CardPrice';
import { useRouter } from '@hooks/useRouter';
import { Base } from '@layouts/Base';
import { Divider } from '@mui/material';
import {
    Detailed_ListingFragment,
    useGetListingQuery,
    useGetUserProfileQuery,
} from 'gql/generated/react';
import Image from 'next/image';
import Carousel from 'nuka-carousel';
import { _404 } from '@components/404';
import React, { FC } from 'react';
import { Card, Container, Grid, Stack } from 'ui';
import Head from 'next/head';

export interface ListingProps {
    listing: Detailed_ListingFragment;
}

export const Listing: FC<ListingProps> = () => {
    const router = useRouter();
    const id = router.query.id as string;

    const response = useGetListingQuery({ variables: { id }, skip: !id });
    const listing = response?.data?.app_listings_by_pk;

    const photos = listing?.photos;
    const user = useGetUserProfileQuery({ variables: listing?.creator })?.data
        ?.app_users_by_pk;

    if (!listing) {
        return <_404 errorMessage={'Listing was not found'} />;
    }

    if (!user) {
        return <_404 errorMessage={'Listing author was not found'} />;
    }

    const image =
        listing.thumbnail?.link ??
        'https://i.pinimg.com/originals/0c/5c/82/0c5c82f69c8516e26deac3258a9bfcd6.png';

    return (
        <Base>
            <Head>
                <title>{listing.title}</title>
            </Head>

            <Container sx={{ marginTop: '3rem' }}>
                <Card>
                    <Grid container direction={'row'}>
                        <Grid item xs={5}>
                            <Carousel
                                wrapAround={true}
                                autoplay={true}
                                autoplayInterval={5000}
                                enableKeyboardControls={true}
                                animation={'zoom'}
                                zoomScale={0.6}
                            >
                                {photos?.map((photo) => (
                                    <Image
                                        src={photo.link}
                                        alt={photo.id}
                                        width={500}
                                        height={500}
                                    />
                                ))}
                            </Carousel>
                        </Grid>
                        <Divider flexItem={true} orientation="vertical" />
                        <Grid item xs={5}>
                            <Stack
                                direction={'column'}
                                sx={{ marginLeft: '5%' }}
                                gap={'5%'}
                            >
                                <h2>{listing.title}</h2>
                                <div>{listing?.description}</div>
                                <CardPrice
                                    price={listing.price}
                                    currency={listing.currency}
                                ></CardPrice>
                                <Stack direction={'row'} gap="1rem">
                                    <div>{user.name}</div>
                                    <div>{user.email}</div>
                                </Stack>
                            </Stack>
                        </Grid>
                    </Grid>
                </Card>
            </Container>
        </Base>
    );
};
